/**
  ******************************************************************************
  * @file           : IS3_INST.h
  * @author         : xin
  * @brief          : None
  * @attention      : None
  * @date           : 2024/8/14
  ******************************************************************************
  */

//
// Created by xin on 2024/8/14.
//

#ifndef IS3LIB_IS3_INST_H
#define IS3LIB_IS3_INST_H
#include "comon.h"
#ifdef __cplusplus
extern "C"   {
#endif

#ifdef _WIN32
#define WINDOWSEXPORT __declspec(dllexport) // Windows下导出函数
#else
#define WINDOWSEXPORT // Linux下导出函数
#endif

WINDOWSEXPORT int IS3SensorInit();
WINDOWSEXPORT  void IS3Set_Serial_FUN(SERIALWRITE writefunc,SERIALWRITE readfunc);
WINDOWSEXPORT STRsensorinfo_C IS3Get_SensorInfo();
WINDOWSEXPORT int IS3OptSnenser(int percent);
WINDOWSEXPORT int IS3GetData(uint16_t *outdata,int shuttertime);
WINDOWSEXPORT int IS3SetWeaveLenthCoeff(double *a,int lenth);
WINDOWSEXPORT void IS3SetShutterOpen(int isopen);
#ifdef __cplusplus
}
#endif


#endif //IS3LIB_IS3_INST_H
